==> haskell-djinn-lib-0.0.1.4-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-djinn-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djinn-lib
version:              0.0.1.4
visibility:           public
id:                   djinn-lib-0.0.1.4-DXI2OBqOsoKIdBAO5A5vcp
key:                  djinn-lib-0.0.1.4-DXI2OBqOsoKIdBAO5A5vcp
license:              BSD-3-Clause
maintainer:           trupill@gmail.com
author:               Lennart Augustsson
homepage:             http://www.augustsson.net/Darcs/Djinn/
synopsis:
    Generate Haskell code from a type. Library extracted from djinn package.

description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is a library extracted from Djinn sources.

category:             Language
abi:                  50cb0c96a06aadff3855b32c6be30bfe
exposed:              True
exposed-modules:      Djinn.HCheck Djinn.HTypes Djinn.LJT Djinn.LJTFormula
import-dirs:          /usr/lib/ghc-9.2.8/site-local/djinn-lib-0.0.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/djinn-lib-0.0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-djinn-lib
hs-libraries:         HSdjinn-lib-0.0.1.4-DXI2OBqOsoKIdBAO5A5vcp
depends:
    base-4.16.4.0 containers-0.6.5.1 mtl-2.2.2 pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-djinn-lib/html/djinn-lib.haddock
haddock-html:         /usr/share/doc/haskell-djinn-lib/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-djinn-lib-0.0.1.4-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-djinn-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 djinn-lib
version:              0.0.1.4
visibility:           public
id:                   djinn-lib-0.0.1.4-3ZhAp6TqnKILDVzcZdWUvX
key:                  djinn-lib-0.0.1.4-3ZhAp6TqnKILDVzcZdWUvX
license:              BSD-3-Clause
maintainer:           trupill@gmail.com
author:               Lennart Augustsson
homepage:             http://www.augustsson.net/Darcs/Djinn/
synopsis:
    Generate Haskell code from a type. Library extracted from djinn package.

description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is a library extracted from Djinn sources.

category:             Language
abi:                  c7c6bd0e2f1548b7b3111a6bfafc79cf
exposed:              True
exposed-modules:      Djinn.HCheck Djinn.HTypes Djinn.LJT Djinn.LJTFormula
import-dirs:          /usr/lib/ghc-9.4.8/site-local/djinn-lib-0.0.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/djinn-lib-0.0.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/djinn-lib-0.0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-djinn-lib
hs-libraries:         HSdjinn-lib-0.0.1.4-3ZhAp6TqnKILDVzcZdWUvX
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2 pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-djinn-lib/html/djinn-lib.haddock
haddock-html:         /usr/share/doc/haskell-djinn-lib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
